import warnings

from django_nine.user import *  # NOQA


warnings.warn(
    "The `nine` namespace is deprecated, use `django_nine` instead.",
    DeprecationWarning
)

warnings.warn(
    "The `django_nine.user` module is deprecated and will be removed in "
    "version 0.3.",
    DeprecationWarning
)



from django_nine import versions as nine_versions

__title__ = 'django_nine.versions'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2015-2020 Artur Barseghyan'
__license__ = 'GPL-2.0-only OR LGPL-2.1-or-later'
__all__ = [
    'versions',
]


def versions(request):
    """Get active theme.

    :param django.http.HttpRequest request:
    :return dict:
    """
    return {'VERSIONS': nine_versions}



__title__ = 'django_nine'
__version__ = '0.2.4'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2015-2020 Artur Barseghyan'
__license__ = 'GPL-2.0-only OR LGPL-2.1-or-later'



import warnings

from django_nine import versions  # NOQA
from django_nine import context_processors  # NOQA

warnings.warn(
    "The `nine` namespace is deprecated, use `django_nine` instead.",
    DeprecationWarning
)



"""
Contains information about the current Django version in use, including (LTE
and GTE).
"""

from distutils.version import LooseVersion

import django

__title__ = 'django_nine.versions'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2015-2020 Artur Barseghyan'
__license__ = 'GPL-2.0-only OR LGPL-2.1-or-later'
__all__ = [
    'LOOSE_DJANGO_VERSION', 'LOOSE_DJANGO_MINOR_VERSION',
]

LOOSE_DJANGO_VERSION = LooseVersion(django.get_version())
LOOSE_DJANGO_MINOR_VERSION = LooseVersion(
    '.'.join([str(i) for i in LOOSE_DJANGO_VERSION.version[0:2]])
)

# Loose versions
LOOSE_VERSIONS = (
    '1.4',
    '1.5',
    '1.6',
    '1.7',
    '1.8',
    '1.9',
    '1.10',
    '1.11',
    '2.0',
    '2.1',
    '2.2',
    '3.0',
    '3.1',
    '3.2',
    '4.0',
    '4.1',
    '4.2',
    '5.0',
    '5.1',
    '5.2',
    '6.0',
    '6.1',
    '6.2',
)

for v in LOOSE_VERSIONS:
    var_name = 'LOOSE_VERSION_{0}'.format(v.replace('.', '_'))
    globals()[var_name] = LooseVersion(v)
    __all__.append(var_name)

# Exact versions
EXACT_VERSIONS = LOOSE_VERSIONS[:-1]

for i, v in enumerate(EXACT_VERSIONS):
    l_cur = globals()['LOOSE_VERSION_{0}'
                      ''.format(LOOSE_VERSIONS[i].replace('.', '_'))]
    l_nxt = globals()['LOOSE_VERSION_{0}'
                      ''.format(LOOSE_VERSIONS[i+1].replace('.', '_'))]
    var_name = 'DJANGO_{0}'.format(v.replace('.', '_'))
    globals()[var_name] = (l_cur <= LOOSE_DJANGO_VERSION < l_nxt)
    __all__.append(var_name)

# LTE list
LTE_VERSIONS = LOOSE_VERSIONS[:-1]

for i, v in enumerate(EXACT_VERSIONS):
    l_cur = globals()['LOOSE_VERSION_{0}'
                      ''.format(LOOSE_VERSIONS[i].replace('.', '_'))]
    var_name = 'DJANGO_LTE_{0}'.format(v.replace('.', '_'))
    globals()[var_name] = (LOOSE_DJANGO_MINOR_VERSION <= l_cur)
    __all__.append(var_name)

# GTE list
GTE_VERSIONS = LOOSE_VERSIONS[:-1]

for i, v in enumerate(EXACT_VERSIONS):
    l_cur = globals()['LOOSE_VERSION_{0}'
                      ''.format(LOOSE_VERSIONS[i].replace('.', '_'))]
    var_name = 'DJANGO_GTE_{0}'.format(v.replace('.', '_'))
    globals()[var_name] = (
        LOOSE_DJANGO_MINOR_VERSION >= l_cur
    )
    __all__.append(var_name)

__all__ = tuple(__all__)

# Clean up
try:
    del l_cur
    del l_nxt
    del var_name
    del i
    del v
except NameError:
    pass

del LooseVersion
del django



import logging

__title__ = 'django_nine.tests.base'
__author__ = 'Artur Barseghyan'
__copyright__ = '2015-2019 Artur Barseghyan'
__license__ = 'GPL-2.0-only OR LGPL-2.1-or-later'
__all__ = (
    'LOG_INFO',
    'log_info',
)


logger = logging.getLogger(__name__)

LOG_INFO = True


def log_info(func):
    """Logs some useful info."""
    if not LOG_INFO:
        return func

    def inner(self, *args, **kwargs):
        result = func(self, *args, **kwargs)

        logger.info('\n\n%s' % func.__name__)
        logger.info('============================')
        if func.__doc__:
            logger.info('""" %s """' % func.__doc__.strip())
        logger.info('----------------------------')
        if result is not None:
            logger.info(result)
        logger.info('\n++++++++++++++++++++++++++++')

        return result
    return inner



import sys
import os
from setuptools import setup, find_packages

try:
    readme = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()
except:
    readme = ''

version = '0.2.4'

install_requires = [
    'Django',
]

tests_require = [
    'Django',
    'mock',
]

try:
    PY2 = sys.version_info[0] == 2
    LTE_PY26 = PY2 and (7 > sys.version_info[1])
    PY3 = sys.version_info[0] == 3

    if LTE_PY26:
        install_requires.append('importlib')
except:
    pass

setup(
    name='django-nine',
    version=version,
    description="Version checking library.",
    long_description="{0}".format(readme),
    classifiers=[
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Environment :: Web Environment",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
        "License :: OSI Approved :: GNU Lesser General Public License v2 or "
        "later (LGPLv2+)",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Development Status :: 4 - Beta",
    ],
    project_urls={
        "Bug Tracker": "https://github.com/barseghyanartur/django-nine/issues",
        "Documentation": "https://django-nine.readthedocs.io/",
        "Source Code": "https://github.com/barseghyanartur/django-nine",
        "Changelog": "https://django-nine.readthedocs.io/"
                     "en/latest/changelog.html",
    },
    keywords='django, compatibility',
    author='Artur Barseghyan',
    author_email='artur.barseghyan@gmail.com',
    url='https://github.com/barseghyanartur/django-nine/',
    package_dir={'': 'src'},
    packages=find_packages(where='./src'),
    license='GPL-2.0-only OR LGPL-2.1-or-later',
    install_requires=install_requires,
    tests_require=tests_require,
    package_data={},
    include_package_data=True,
)



# import unittest
# import mock
# # For Python3 >= 3.4
# try:
#     from importlib import reload
# # For Python3 < 3.4
# except ImportError as err:
#     try:
#         from imp import reload
#     except ImportError as err:
#         pass
#
# from django.urls import reverse
# from django.test import RequestFactory, TestCase
#
# from .base import log_info
#
# __title__ = 'django_nine.tests.test_versions'
# __author__ = 'Artur Barseghyan'
# __copyright__ = 'Copyright (c) 2015 Artur Barseghyan'
# __license__ = 'GPL-2.0-only OR LGPL-2.1-or-later'
# __all__ = ('ContextProcessorsTest',)
#
#
# class ContextProcessorsTest(TestCase):
#     """
#     Tests of ``django_nine.context_processors`` module.
#     """
#     def setUp(self):
#         self.factory = RequestFactory()
#
#     @log_info
#     @mock.patch('django.get_version', mock.MagicMock(return_value='2.1'))
#     def test_django_2_1(self):
#         """
#         Tests as if we were using Django==2.1.
#         """
#         from django_nine import versions
#         reload(versions)
#
#         url = reverse('django_nine')
#         response = self.client.get(url)
#
#         import pytest; pytest.set_trace()
#
#
# if __name__ == "__main__":
#     unittest.main()
